@@ -101,6 +101,8 @@
 #'   A list with:
 #'   \tabular{ll}{
 #'     \code{call} \tab Matched call. \cr
+#'     \code{formula} \tab formula in the call or \emph{NULL}. \cr
+#'     \code{data} \tab data.frame used as database or \emph{NULL}. \cr
 #'     \code{type} \tab  Type of model specified. \cr
 #'     \code{Durbin} \tab Value of \code{Durbin} argument. \cr
 #'     \code{coefficients} \tab Estimated coefficients for the regressors. \cr
@@ -126,8 +128,8 @@
 #'     \code{N} \tab Number of cross-sections or spatial units. \cr
 #'     \code{Tm} \tab Number of time periods. \cr
 #'     \code{p} \tab Number of regressors by equation (including intercepts). \cr
-#'     \code{Y} \tab Vector \emph{Y} of the explained variables of the SUR model. \cr
-#'     \code{X} \tab Matrix \emph{X} of the regressors of the SUR model. \cr
+#'     \code{Y} \tab If \emph{data} is \emph{NULL}, vector \emph{Y} of the explained variables of the SUR model. \cr
+#'     \code{X} \tab If \emph{data} is \emph{NULL}, matrix \emph{X} of the regressors of the SUR model. \cr
 #'     \code{W} \tab Spatial weighting matrix. \cr
 #'     \code{zero.policy} \tab Logical value of \code{zero.policy} . \cr
 #'     \code{listw_style} \tab	Style of neighborhood matrix \code{W}. \cr
@@ -146,9 +148,11 @@
 #'       \item López, F. A., Mínguez, R., Mur, J. (2020). ML versus IV estimates 
 #'       of spatial SUR models: evidence from the case of Airbnb in Madrid urban 
 #'       area. \emph{The Annals of Regional Science}, 64(2), 313-347.
+#'       <doi:10.1007/s00168-019-00914-1>
 #'       \item Anselin, L. (2016) Estimation and Testing in the Spatial Seemingly 
 #'       Unrelated Regression (SUR). \emph{Geoda Center for Geospatial Analysis 
 #'       and Computation, Arizona State University}. Working Paper 2016-01.
+#'       <doi:10.13140/RG.2.2.15925.40163>
 #'       \item, Anselin, L. (1988). \emph{Spatial Econometrics: Methods and Models}. 
 #'       Kluwer Academic Publishers, Dordrecht, The Netherlands (p. 146).
 #'       \item Anselin, L., Le Gallo, J., Hubert J. (2008) Spatial Panel Econometrics. 
@@ -421,8 +425,8 @@ spsur3sls <- function(formula = NULL, data = NULL, na.action,
     coefficients <- coefforig
     rest.se <- seorig
   }  
-  ret <- new_spsur(list(call = cl, type = type, 
-                        Durbin = Durbin, 
+  ret <- new_spsur(list(call = cl, type = type, formula = formula,
+                        data = data, W = W, Durbin = Durbin, 
                         G = G, N = N, Tm = Tm, 
                         deltas = deltas, 
                         deltas.se = deltas.se,  
@@ -432,13 +436,13 @@ spsur3sls <- function(formula = NULL, data = NULL, na.action,
                         p = p, 
                         dvars = if(exists("dvars")) dvars else NULL,
                         parameters = parameters,
-                        BP=BP,
+                        BP = BP,
                         R2 = c(R2_pool,R2_eq),
                         Sigma = Sigma, 
                         residuals = z$residuals, 
                         df.residual = df.residual,
-                        fitted.values = z$fitted.values, 
-                        Y = Y, X = X, W = W, 
+                        fitted.values = z$fitted.values,
+                        Y = Y, X = X,  
                         zero.policy = zero.policy, 
                         listw_style = listw$style, 
                         maxlagW = maxlagW))
